yakumo

Package yakumo |
[hide private]
[frames] | no frames]

# Package yakumo

source code

Client class definition

Submodules | [hide private]
yakumo.base: Abstract classes for resource management yakumo.cinder yakumo.cinder.v1: Sub client class for Cinder API v1 yakumo.cinder.v1.snapshot: Resource class and its manager for volumes on Block Storage V1 API yakumo.cinder.v1.volume: Resource class and its manager for volumes on Block Storage V1 API yakumo.cinder.v1.volume_type: Resource class and its manager for volumes on Block Storage V1 API yakumo.cinder.v2: Sub client class for Cinder API V2 yakumo.cinder.v2.consistency_group: Resource class and its manager for consistency group on Block Storage V2 API yakumo.cinder.v2.consistency_group_snapshot: Resource class and its manager for consistency group snapshot on Block Storage V2 API yakumo.cinder.v2.qos: Resource class and its manager for QoS specifications on Block Storage V2 API yakumo.cinder.v2.quota_set: Resource class and its manager for Quota sets in Block Storage API v2 yakumo.cinder.v2.service: Resource class and its manager for services in Block Storage API v2 yakumo.cinder.v2.snapshot: Resource class and its manager for volume snapshots on Block Storage V2 API yakumo.cinder.v2.volume: Resource class and its manager for volumes on Block Storage V2 API yakumo.cinder.v2.volume_backup: Resource class and its manager for volume backup on Block Storage V2 API yakumo.cinder.v2.volume_transfer: Resource class and its manager for volume transfer on Block Storage V2 API yakumo.cinder.v2.volume_type: Resource class and its manager for volume types on Block Storage V2 API yakumo.cmd yakumo.cmd.ossh yakumo.constant: Constants yakumo.exception: Exception classes yakumo.glance yakumo.glance.v1: Sub client class for Glance API v1 yakumo.glance.v1.image: Resource class and its manager for images in Image V1 API yakumo.glance.v2: Sub client class for Glance API v2 yakumo.glance.v2.image: Resource class and its manager for images in Image V2 API yakumo.glance.v2.image_member: Resource class and its manager for image members in Image V2 API yakumo.keystone yakumo.keystone.v2: Sub client class for Identity V2 API yakumo.keystone.v2.endpoint: Resource class and its manager for endpoints in Identity V2 API yakumo.keystone.v2.project: Resource class and its manager for projects in Identity V2 API yakumo.keystone.v2.role: Resource class and its manager for roles in Identity V2 API yakumo.keystone.v2.service: Resource class and its manager for services in Identity V2 API yakumo.keystone.v2.user: Resource class and its manager for users in Identity V2 API yakumo.keystone.v3: Sub client class for Identity V3 API yakumo.keystone.v3.credential: Resource class and its manager for credentials in Identity V3 API yakumo.keystone.v3.domain: Resource class and its manager for domains in Identity V3 API yakumo.keystone.v3.endpoint: Resource class and its manager for endpoints in Identity V3 API yakumo.keystone.v3.group: Resource class and its manager for groups in Identity V3 API yakumo.keystone.v3.project: Resource class and its manager for projects in Identity V3 API yakumo.keystone.v3.region: Resource class and its manager for regions in Identity V3 API yakumo.keystone.v3.role: Resource class and its manager for roles in Identity V3 API yakumo.keystone.v3.service: Resource class and its manager for services in Identity V3 API yakumo.keystone.v3.user: Resource class and its manager for users in Identity V3 API yakumo.mapper: Mapper classes yakumo.neutron yakumo.neutron.v2 yakumo.neutron.v2.floating_ip: Resource class and its manager for floating IPs in Networking V2 API yakumo.neutron.v2.lb yakumo.neutron.v2.lb.health_monitor: Resource class and its manager for LB Health Monitors in Networking V2 API yakumo.neutron.v2.lb.member: Resource class and its manager for LB backend members in Networking V2 API yakumo.neutron.v2.lb.pool: Resource class and its manager for LB Pools in Networking V2 API yakumo.neutron.v2.lb.vip: Resource class and its manager for LB virtual IPs in Networking V2 API yakumo.neutron.v2.lbaas yakumo.neutron.v2.lbaas.health_monitor: Resource class and its manager for LBaaS Health Monitors in Networking V2 API yakumo.neutron.v2.lbaas.listener: Resource class and its manager for LBaaS listeners in Networking V2 API yakumo.neutron.v2.lbaas.load_balancer: Resource class and its manager for LBaaS load balancers in Networking V2 API yakumo.neutron.v2.lbaas.member: Resource class and its manager for LBaaS backend members in Networking V2 API yakumo.neutron.v2.lbaas.pool: Resource class and its manager for LBaaS Pools in Networking V2 API yakumo.neutron.v2.metering yakumo.neutron.v2.metering.label: Resource class and its manager for metering labels for Networking v2 API yakumo.neutron.v2.metering.rule: Resource class and its manager for metering label rules for Networking v2 API yakumo.neutron.v2.network: Resource class and its manager for networks in Networking V2 API yakumo.neutron.v2.port: Resource class and its manager for ports in Networking V2 API yakumo.neutron.v2.quota: Resource class and its manager for quotas in Networking V2 API yakumo.neutron.v2.router: Resource class and its manager for routers in Networking V2 API yakumo.neutron.v2.security_group: Resource class and its manager for security groups in Networking V2 API yakumo.neutron.v2.security_group_rule: Resource class and its manager for security group rules in Networking V2 API yakumo.neutron.v2.subnet: Resource class and its manager for subnets in Networking V2 API yakumo.neutron.v2.subnet_pool: Resource class and its manager for subnet pools in Compute API v2 yakumo.neutron.v2.vpn yakumo.neutron.v2.vpn.ike_policy: Resource class and its manager for VPN IKE policies in Networking V2 API yakumo.neutron.v2.vpn.ipsec_policy: Resource class and its manager for VPN IPSec policies in Networking V2 API yakumo.neutron.v2.vpn.ipsec_site_connection: Resource class and its manager for VPN IPSec site connections in Networking V2 API yakumo.neutron.v2.vpn.service: Resource class and its manager for VPN services in Networking V2 API yakumo.nova yakumo.nova.v2: Sub client class for Nova API v2 yakumo.nova.v2.agent: Resource class and its manager for agents in Compute API v2 yakumo.nova.v2.aggregate: Resource class and its manager for aggregates in Compute API v2 yakumo.nova.v2.availability_zone: Resource class and its manager for availability zones in Compute API v2 yakumo.nova.v2.certificate: Resource class and its manager for root certificates in Compute API v2 yakumo.nova.v2.cloudpipe: Resource class and its manager for cloudpipes in Compute API v2 yakumo.nova.v2.fixed_ip: Resource class and its manager for fixed IPs in Compute API v2 yakumo.nova.v2.flavor: Resource class and its manager for flavors in Compute API v2 yakumo.nova.v2.floating_ip: Resource class and its manager for floating IPs in Compute API v2 yakumo.nova.v2.floating_ip_bulk: Resource class and its manager for floating IP bulks in Compute API v2 yakumo.nova.v2.floating_ip_dns: Resource class and its manager for floating IP DNS entries in Compute API v2 yakumo.nova.v2.hypervisor: Resource class and its manager for hypervisors in Compute API v2 yakumo.nova.v2.image: Resource class and its manager for images in Compute API v2 yakumo.nova.v2.interface_attachment: Resource class and its manager for interface attachment in Compute API v2 yakumo.nova.v2.key_pair: Resource class and its manager for key pairs in Compute API v2 yakumo.nova.v2.network: Resource class and its manager for networks in Compute API v2 yakumo.nova.v2.quota_set: Resource class and its manager for Quota sets in Compute API v2 yakumo.nova.v2.security_group: Resource class and its manager for security groups in Compute API v2 yakumo.nova.v2.security_group_default_rule: Resource class and its manager for security group default rules in Compute API v2 yakumo.nova.v2.security_group_rule: Resource class and its manager for security group rules in Compute API v2 yakumo.nova.v2.server: Resource class and its manager for servers in Compute API v2 yakumo.nova.v2.server_group: Resource class and its manager for server groups in Compute API v2 yakumo.nova.v2.service: Resource class and its manager for services in Compute API v2 yakumo.nova.v2.volume_attachment: Resource class and its manager for volume attachment in Compute API v2 yakumo.patch yakumo.session: utility function(s) for session yakumo.utils: Miscellaneous functions/decorators

Classes | [hide private]
| Client

Variables | [hide private]
| __package__ = ``'``yakumo``'``